Models
======

.. currentmodule:: hhpy.modelling

.. autoclass:: Models
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Models.fit
      ~Models.k_split
      ~Models.model_by_name
      ~Models.predict
      ~Models.score
      ~Models.scoreplot
      ~Models.train

   .. rubric:: Methods Documentation

   .. automethod:: fit
   .. automethod:: k_split
   .. automethod:: model_by_name
   .. automethod:: predict
   .. automethod:: score
   .. automethod:: scoreplot
   .. automethod:: train
